@@ -1,9 +1,15 @@
 """Constants for the PyISY Module."""
 import datetime
+import logging
 from xml.parsers.expat import ExpatError
 
+_LOGGER = logging.getLogger(__package__)
+LOG_LEVEL = logging.DEBUG
+LOG_VERBOSE = 5
+LOG_FORMAT = "%(asctime)s %(levelname)s [%(name)s] %(message)s"
+LOG_DATE_FORMAT = "%Y-%m-%d %H:%M:%S"
+
 UPDATE_INTERVAL = 0.5
-VERBOSE = 5  # Verbose Logging Level
 
 
 # Time Constants / Strings
@@ -23,7 +29,18 @@ RECONNECT_DELAY = 60
 SOCKET_BUFFER_SIZE = 4096
 THREAD_SLEEP_TIME = 30.0
 
+ES_LOST_STREAM_CONNECTION = "lost_stream_connection"
+ES_CONNECTED = "connected"
+ES_DISCONNECTED = "disconnected"
+ES_START_UPDATES = "start_updates"
+ES_STOP_UPDATES = "stop_updates"
+ES_INITIALIZING = "stream_initializing"
+ES_LOADED = "stream_loaded"
+ES_RECONNECT_FAILED = "reconnect_failed"
+ES_RECONNECTING = "reconnecting"
+
 ISY_VALUE_UNKNOWN = -1 * float("inf")
+ISY_PROP_NOT_SET = "-1"
 
 XML_ERRORS = (AttributeError, KeyError, ValueError, TypeError, IndexError, ExpatError)
 XML_PARSE_ERROR = "ISY Could not parse response, poorly formatted XML."
@@ -39,6 +56,8 @@ ATTR_FORMATTED = "formatted"
 ATTR_ID = "id"
 ATTR_INIT = "init"
 ATTR_INSTANCE = "instance"
+ATTR_LAST_CHANGED = "last_changed"
+ATTR_LAST_UPDATE = "last_update"
 ATTR_NODE_DEF_ID = "nodeDefId"
 ATTR_PARENT = "parentId"
 ATTR_PRECISION = "prec"
@@ -108,6 +127,7 @@ PROTO_ZWAVE = "zwave"
 
 PROP_BATTERY_LEVEL = "BATLVL"
 PROP_BUSY = "BUSY"
+PROP_COMMS_ERROR = "ERR"
 PROP_ENERGY_MODE = "CLIEMD"
 PROP_HEAT_COOL_STATE = "CLIHCS"
 PROP_HUMIDITY = "CLIHUM"
@@ -197,7 +217,7 @@ COMMAND_FRIENDLY_NAME = {
     "DON5": "on_5x_key_presses",
     "ELECCON": "electrical_conductivity",
     "ELECRES": "electrical_resistivity",
-    "ERR": "device_communication_errors",
+    PROP_COMMS_ERROR: "device_communication_errors",
     "GPV": "general_purpose",
     "GV0": "custom_control_0",
     "GV1": "custom_control_1",
@@ -321,9 +341,11 @@ UOM_SECONDS = "57"
 UOM_FAN_MODES = "99"
 UOM_CLIMATE_MODES = "98"
 UOM_CLIMATE_MODES_ZWAVE = "67"
+UOM_DOUBLE_TEMP = "101"
 
 UOM_FRIENDLY_NAME = {
     "1": "A",
+    "2": "",  # Binary / On-Off
     "3": "btu/h",
     "4": "°C",
     "5": "cm",
@@ -402,6 +424,7 @@ UOM_FRIENDLY_NAME = {
     "90": "Hz",
     "91": "°",
     "92": "° South",
+    "100": "",
     "101": "° (x2)",
     "102": "kWs",
     "103": "$",
@@ -417,8 +440,8 @@ UOM_FRIENDLY_NAME = {
     "113": "",  # raw 3-byte signed value
     "114": "",  # raw 4-byte signed value
     "116": "mi",
-    "117": "mb",
-    "118": "hpa",
+    "117": "mbar",
+    "118": "hPa",
     "119": "Wh",
     "120": "in/day",
 }
@@ -664,8 +687,16 @@ INSTEON_RAMP_RATES = {
 
 # Thermostat Types/Categories. 4.8 Trane, 5.3 venstar, 5.10 Insteon Wireless,
 #  5.11 Insteon, 5.17 Insteon (EU), 5.18 Insteon (Aus/NZ)
-THERMOSTAT_TYPES = ["4.8", "5.3", "5.10", "5.11", "5.17", "5.18"]
-THERMOSTAT_ZWAVE_CAT = ["140"]
+INSTEON_TYPE_THERMOSTAT = ["4.8", "5.3", "5.10", "5.11", "5.17", "5.18"]
+ZWAVE_CAT_THERMOSTAT = ["140"]
+
+# Other special categories or types
+INSTEON_TYPE_LOCK = ["4.64"]
+ZWAVE_CAT_LOCK = ["111"]
+
+INSTEON_TYPE_DIMMABLE = ["1."]
+INSTEON_SUBNODE_DIMMABLE = " 1"
+ZWAVE_CAT_DIMMABLE = ["109", "119", "186"]
 
 # Referenced from ISY-WSDK 4_fam.xml
 # Included for user translations in external modules.
@@ -802,3 +833,40 @@ NODE_CATEGORIES = {
     "127": "virtual",
     "254": "unknown",
 }
+
+# Node Change Actions
+NC_NODE_RENAMED = "NN"
+NC_NODE_REMOVED = "NR"
+NC_NODE_MOVED = "MV"
+NC_NODE_REMOVE_FROM_GROUP = "RG"
+NC_NODE_ENABLED = "RG"
+NC_PARENT_CHANGED = "PC"
+NC_GROUP_RENAMED = "GN"
+NC_GROUP_REMOVED = "GR"
+NC_GROUP_ADDED = "GD"
+NC_FOLDER_RENAMED = "FN"
+NC_FOLDER_REMOVED = "FR"
+NC_FOLDER_ADDED = "FD"
+NC_NODE_ERROR = "NE"
+NC_CLEAR_ERROR = "CE"
+NC_NET_RENAMED = "WR"
+NC_NODE_REVISED = "RV"
+
+NODE_CHANGED_ACTIONS = [
+    NC_NODE_RENAMED,
+    NC_NODE_REMOVED,
+    NC_NODE_MOVED,
+    NC_NODE_REMOVE_FROM_GROUP,
+    NC_NODE_ENABLED,
+    NC_PARENT_CHANGED,
+    NC_GROUP_RENAMED,
+    NC_GROUP_REMOVED,
+    NC_GROUP_ADDED,
+    NC_FOLDER_RENAMED,
+    NC_FOLDER_REMOVED,
+    NC_FOLDER_ADDED,
+    NC_NODE_ERROR,
+    NC_CLEAR_ERROR,
+    NC_NET_RENAMED,
+    NC_NODE_REVISED,
+]
